@@ -1,5 +1,6 @@
 from minio import Minio
 import os
+import io
 
 class PyMinio:
     def __init__(self, host, port, access_key, secret_key, secure=False):
@@ -44,6 +45,9 @@ class PyMinio:
         )
         return True
 
+    def write(self, object_name, content:bytes):
+        self.client.put_object(self.bucket, object_name, io.BytesIO(content), len(content))
+
     def exists(self, object_name:str, *, trim:bool=False) -> bool:
         object_name = self._trim_bucket(object_name, trim=trim)
 
